Raw score
=========

Methods
-------

.. autosummary::
   :nosignatures:

   ase_ga.set_raw_score
   ase_ga.get_raw_score

Documentation
-------------
   
.. automodule:: ase_ga.__init__
   :members:
   :member-order: bysource
